@@ -2,6 +2,7 @@
 from ..const import API_PATH
 from .listing.generator import ListingGenerator
 from .base import PRAWBase
+from .util import stream_generator
 
 
 class Inbox(PRAWBase):
@@ -24,6 +25,34 @@ class Inbox(PRAWBase):
         return ListingGenerator(self._reddit, API_PATH['inbox'],
                                 **generator_kwargs)
 
+    def collapse(self, items):
+        """Mark an inbox message as collapsed.
+
+        :param items: A list containing instances of :class:`.Message`.
+
+        Requests are batched at 25 items (reddit limit).
+
+        For example, to collapse all unread Messages, try:
+
+        .. code:: python
+
+            from praw.models import Message
+            unread_messages = []
+            for item in reddit.inbox.unread(limit=None):
+                if isinstance(item, Message):
+                    unread_messages.append(item)
+            reddit.inbox.collapse(unread_messages)
+
+        .. seealso::
+
+           :meth:`.Message.uncollapse`
+
+        """
+        while items:
+            data = {'id': ','.join(x.fullname for x in items[:25])}
+            self._reddit.post(API_PATH['collapse'], data=data)
+            items = items[25:]
+
     def comment_replies(self, **generator_kwargs):
         """Return a ListingGenerator for comment replies.
 
@@ -131,8 +160,7 @@ class Inbox(PRAWBase):
 
         """
         listing = self._reddit.get(API_PATH['message'].format(id=message_id))
-        messages = [listing[0]] + list(self._reddit._objector
-                                       .objectify(listing[0].replies))
+        messages = [listing[0]] + listing[0].replies
         while messages:
             message = messages.pop(0)
             if message.id == message_id:
@@ -161,7 +189,7 @@ class Inbox(PRAWBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to output the receipient of the mot recent 15 messages
+        For example, to output the recipient of the most recent 15 messages
         try:
 
         .. code:: python
@@ -173,6 +201,24 @@ class Inbox(PRAWBase):
         return ListingGenerator(self._reddit, API_PATH['sent'],
                                 **generator_kwargs)
 
+    def stream(self, **stream_options):
+        """Yield new inbox items as they become available.
+
+        Items are yielded oldest first. Up to 100 historical items will
+        initially be returned.
+
+        Keyword arguments are passed to :func:`.stream_generator`.
+
+        For example, to retrieve all new inbox items, try:
+
+        .. code:: python
+
+           for item in reddit.inbox.stream():
+               print(item)
+
+        """
+        return stream_generator(self.unread, **stream_options)
+
     def submission_replies(self, **generator_kwargs):
         """Return a ListingGenerator for submission replies.
 
@@ -190,16 +236,41 @@ class Inbox(PRAWBase):
         return ListingGenerator(self._reddit, API_PATH['submission_replies'],
                                 **generator_kwargs)
 
+    def uncollapse(self, items):
+        """Mark an inbox message as uncollapsed.
+
+        :param items: A list containing instances of :class:`.Message`.
+
+        Requests are batched at 25 items (reddit limit).
+
+        For example, to uncollapse all unread Messages, try:
+
+        .. code:: python
+
+            from praw.models import Message
+            unread_messages = []
+            for item in reddit.inbox.unread(limit=None):
+                if isinstance(item, Message):
+                    unread_messages.append(item)
+            reddit.inbox.uncollapse(unread_messages)
+
+        .. seealso::
+
+           :meth:`.Message.collapse`
+
+        """
+        while items:
+            data = {'id': ','.join(x.fullname for x in items[:25])}
+            self._reddit.post(API_PATH['uncollapse'], data=data)
+            items = items[25:]
+
     def unread(self, mark_read=False, **generator_kwargs):
         """Return a ListingGenerator for unread comments and messages.
 
-        :param mark_read: Marks the messages as read when they're obtained
-            (default: False).
+        :param mark_read: Marks the inbox as read (default: False).
 
-        .. note:: When marking messages as read, the entire batch (up to 100 at
-                  a time) is marked as read when fetched. Failure to consume
-                  the entire listing may result in missed messages if you only
-                  obtain unread messages.
+        .. note:: This only marks the inbox as read not the messages. Use
+                  :meth:`.Inbox.mark_read` to mark the messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -214,6 +285,7 @@ class Inbox(PRAWBase):
                    print(item.author)
 
         """
-        params = {'mark': mark_read}
+        self._safely_add_arguments(
+            generator_kwargs, 'params', mark=mark_read)
         return ListingGenerator(self._reddit, API_PATH['unread'],
-                                params=params, **generator_kwargs)
+                                **generator_kwargs)
