@@ -9,7 +9,56 @@ from .mixins import MessageableMixin
 
 
 class Redditor(RedditBase, MessageableMixin, RedditorListingMixin):
-    """A class representing the users of reddit."""
+    """A class representing the users of reddit.
+
+    **Typical Attributes**
+
+    This table describes attributes that typically belong to objects of this
+    class. Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a
+    guarantee that these attributes will always be present, nor is this list
+    comprehensive in any way.
+
+    ==================================== ======================================
+    Attribute                            Description
+    ==================================== ======================================
+    ``comment_karma``                    The comment karma for the Redditor.
+    ``comments``                         Provide an instance of
+                                         :class:`.SubListing` for comment
+                                         access.
+    ``created_utc``                      Time the account was created,
+                                         represented in `Unix Time`_.
+    ``has_verified_email``               Whether or not the Redditor has
+                                         verified their email.
+    ``icon_img``                         The url of the Redditors' avatar.
+    ``id``                               The ID of the Redditor.
+    ``is_employee``                      Whether or not the Redditor is a
+                                         Reddit employee.
+    ``is_friend``                        Whether or not the Redditor is friends
+                                         with the authenticated client.
+    ``is_gold``                          Whether or not the Redditor has active
+                                         gold status.
+    ``link_karma``                       The link karma for the Redditor.
+    ``name``                             The Redditor's username.
+    ``subreddit``                        If the Redditor has created a
+                                         user-subreddit, provides a dictionary
+                                         of additional attributes. See below.
+    ``subreddit['banner_img']``          The url of the user-subreddit banner.
+    ``subreddit['name']``                The name of the user-subreddit
+                                         (prefixed with 't5').
+    ``subreddit['over_18']``             Whether or not the user-subreddit is
+                                         NSFW.
+    ``subreddit['public_description']``  The public description of the user-
+                                         subreddit.
+    ``subreddit['subscribers']``         The number of users subscribed to the
+                                         user-subreddit.
+    ``subreddit['title']``               The title of the user-subreddit.
+    ==================================== ======================================
+
+
+    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+
+    """
 
     STR_FIELD = 'name'
 
@@ -55,6 +104,9 @@ class Redditor(RedditBase, MessageableMixin, RedditorListingMixin):
         """
         if bool(name) == bool(_data):
             raise TypeError('Either `name` or `_data` must be provided.')
+        if _data:
+            assert isinstance(_data, dict) and 'name' in _data, \
+                   'Please file a bug with PRAW'
         super(Redditor, self).__init__(reddit, _data)
         self._listing_use_sort = True
         if name:
@@ -110,6 +162,26 @@ class Redditor(RedditBase, MessageableMixin, RedditorListingMixin):
         """Return a list of the redditor's public multireddits."""
         return self._reddit.get(API_PATH['multireddit_user'].format(user=self))
 
+    def trophies(self):
+        """Return a list of the redditor's trophies.
+
+        :returns: A ``list`` of :class:`~praw.models.Trophy` objects.
+            Return ``[]`` if the redditor has no trophy.
+
+        Raise ``prawcore.exceptions.BadRequest`` if the redditor doesn't exist.
+
+        Usage:
+
+        .. code:: python
+
+            for trophy in reddit.redditor('spez').trophies():
+                print(trophy.name)
+                print(trophy.description)
+
+        """
+        return list(self._reddit.get(
+            API_PATH['trophies'].format(user=self)))
+
     def unblock(self):
         """Unblock the Redditor."""
         data = {'container': self._reddit.user.me().fullname,
